from traceback import print_exc
try:
    import pg8000
except ImportError:
    raise ImportError('pg8000 must be installed! Command: pip install pg8000')


class Database:
        def __init__(self):
            self.config = None
            self.conn = None

        def __del__(self):
            if self.conn:
                self.conn.close()

        def commit(self):
            try:
                self.conn.commit()
            except:
                print_exc()
                # Attempt database connection re-establishment.
                self.connect(self.config, reestablish=True)
                return self.commit()

        def connect(self, config_obj, dont_try_again=False, reestablish=False):
            self.config = config_obj
            if not self.conn or reestablish:
                self.conn = pg8000.connect(**config_obj.database)
                if not dont_try_again:
                    return self.connect(config_obj, True)

        def execute(self, stmt, params=[]):
            try:
                cursor = self.conn.cursor()
                cursor.execute(stmt, params)
                return cursor
            except:
                print_exc()
                # Attempt database connection re-establishment.
                self.connect(self.config, reestablish=True)
                return self.execute(stmt, params)