from tornadokick.web import Application, RequestHandler
from tornadokick.web import namespace


CMS = 'cms'


class MyRequestHandler(RequestHandler):
    @classmethod
    def route(cls):
        return [
            r'/p/?',
            r'/p/([0-9]+)?',
            r'/parameter/([0-9]+)?',
        ]

    def get(self, status=None):
        if status is None:
            status = 0
        msg = {
            'parameter': int(status),
        }
        self.write_json(msg)

@namespace(CMS)
class StatusRequestHandler(RequestHandler):
    @classmethod
    def route(cls):
        return '/hello/?'

    def template_filename(cls):
        return 'hello.html'

    def get(self):
        self.set_template_context_key('status', 'Welcome to Tornado Kick.')
        # Renders the template to user agent.
        self.template_render()


def main():
    from os.path import dirname, join
    handlers = [
        MyRequestHandler,
        StatusRequestHandler,
    ]
    template_root = join(dirname(__file__), 'views')
    settings = {
        'template_path': template_root,
    }
    app = Application(handlers, **settings)
    app.listen(8888)
    # Starts Tornado IO loop
    print('Running Tornado Kick example application')
    app.start()
