from datetime import datetime
from decimal import Decimal
import json
import re


DATETIME_FORMAT = '%Y-%m-%d %H:%M:%S'


class Encoder(json.JSONEncoder):
    def default(self, obj):
        from .store import StoreObject
        if isinstance(obj, StoreObject):
            return obj.__dict__
        elif isinstance(obj, Decimal):
            return float(obj)
        elif isinstance(obj, datetime):
            return obj.strftime(DATETIME_FORMAT)
        return super().default(obj)


def convert_to_datetime(obj):
    if isinstance(obj, dict):
        for k, v in obj.items():
            obj[k] = convert_to_datetime(v)
    elif isinstance(obj, str):
        return convert_str_to_datetime(obj)
    return obj


def convert_str_to_datetime(s):
    pattern = r'^[0-9]{4}-[0-9]{1,2}-[0-9]{1,2} [0-9]{1,2}:[0-9]{1,2}:[0-9]{1,2}$'
    if re.match(pattern, s):
        return datetime.strptime(s, DATETIME_FORMAT)
    else:
        return s


def dumps(obj):
    return json.dumps(obj, cls=Encoder)


def loads(s):
    obj = json.loads(s, parse_float=Decimal)
    obj = convert_to_datetime(obj)
    return obj